@@ -47,6 +47,7 @@ class EnvironementConfig:
         self.ODOO_DEPENDS = base_env_vars.get("ODOO_DEPENDS")
         self.DUMP_PATH = base_env_vars.get("PATH_DUMP")
         self.NO_DB_DUMP: bool = base_env_vars.get("NO_DB_DUMP", str(False)).capitalize() == str(True).capitalize()
+        self.MODULES_WITHOUT_DEMO: str = base_env_vars.get("MODULES_WITHOUT_DEMO", str(False).capitalize())
         self.NESTOR_CFG_FILENAME = os.environ.get("NESTOR_CFG_FILENAME", ".nestor-cfg.yml")
         self.BASE_MODULE_UPDATE = os.environ.get("BASE_MODULE_UPDATE", "all")
         self.MODULE_TO_INSTALL = os.environ.get("MODULE_TO_INSTALL")
@@ -397,7 +398,7 @@ class PreviewUpScript(ScriptNestor):
         return 0
 
     def add_with_demo_option(self, values):
-        return values.merge(NestorDescSet([NestorOpt("options.withoutDemo", "False")]))
+        return values.merge(NestorDescSet([NestorOpt("options.withoutDemo", self.config.MODULES_WITHOUT_DEMO)]))
 
 
 class PreviewDownScript(ScriptNestor):
